from distutils.core import setup
setup(
  name='Clarissa',
  packages=['ClarissaPackages', 'ClarissaPackages3'],
  version='1.1.1',
  description='Talk to me, Clarissa Campbell, your favorite bot',
  author='Indie Dev',
  author_email='bremo.lincolin101@gmail.com',
  url='https://github.com/Clarissa-Bot/Setup/archive/master.zip',
  keywords=['Clarissa', 'Python bot', 'tree person'],
  classifiers = [],
  )